## This file runs two sets of survival analyses using dead recovery models. NB, in order for RMark to run, Program MARK (http://www.phidot.org/software/mark/) must first be installed. The first set of models assesses spatial and temporal variation in survival rates. The second assess how well different weather models explain any such temporal variance.


## This first batch of code will run the first set of models to assess spatial and temporal variation, starting by loading and processing the data. 
library("RMark")

setwd("C:/Users/kevin.wood/Documents/Icelandic_Eider_AF_revised/DeadRecoveryModel")

eiders=read.table(file="Eider_dead_recovery.txt",header=TRUE,
                  colClasses=c("character","factor"))

eiders.processed=process.data(eiders,begin.time=1982,model="Recovery",groups=c("site"))

eiders.ddl=make.design.data(eiders.processed)

## Specify valus to be used in temporal models
eiders.ddl$S$threeyear[eiders.ddl$S$time==1982]="A"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1983]="A"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1984]="A"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1985]="B"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1986]="B"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1987]="B"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1988]="C"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1989]="C"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1990]="C"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1991]="D"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1992]="D"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1993]="D"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1994]="E"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1995]="E"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1996]="E"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1997]="F"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1998]="F"
eiders.ddl$S$threeyear[eiders.ddl$S$time==1999]="F"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2000]="G"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2001]="G"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2002]="G"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2003]="H"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2004]="H"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2005]="H"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2006]="I"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2007]="I"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2008]="I"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2009]="J"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2010]="J"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2011]="J"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2012]="K"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2013]="K"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2014]="K"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2015]="L"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2016]="L"
eiders.ddl$S$threeyear[eiders.ddl$S$time==2017]="L"

eiders.ddl$r$threeyear[eiders.ddl$r$time==1982]="A"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1983]="A"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1984]="A"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1985]="B"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1986]="B"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1987]="B"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1988]="C"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1989]="C"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1990]="C"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1991]="D"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1992]="D"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1993]="D"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1994]="E"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1995]="E"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1996]="E"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1997]="F"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1998]="F"
eiders.ddl$r$threeyear[eiders.ddl$r$time==1999]="F"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2000]="G"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2001]="G"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2002]="G"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2003]="H"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2004]="H"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2005]="H"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2006]="I"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2007]="I"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2008]="I"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2009]="J"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2010]="J"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2011]="J"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2012]="K"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2013]="K"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2014]="K"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2015]="L"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2016]="L"
eiders.ddl$r$threeyear[eiders.ddl$r$time==2017]="L"

eiders.ddl$S$fiveyear[eiders.ddl$S$time==1982]="A"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1983]="A"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1984]="A"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1985]="A"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1986]="A"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1987]="B"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1988]="B"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1989]="B"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1990]="B"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1991]="B"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1992]="C"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1993]="C"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1994]="C"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1995]="C"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1996]="C"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1997]="D"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1998]="D"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==1999]="D"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2000]="D"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2001]="D"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2002]="E"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2003]="E"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2004]="E"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2005]="E"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2006]="E"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2007]="F"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2008]="F"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2009]="F"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2010]="F"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2011]="F"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2012]="G"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2013]="G"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2014]="G"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2015]="G"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2016]="G"
eiders.ddl$S$fiveyear[eiders.ddl$S$time==2017]="H"

eiders.ddl$r$fiveyear[eiders.ddl$r$time==1982]="A"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1983]="A"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1984]="A"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1985]="A"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1986]="A"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1987]="B"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1988]="B"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1989]="B"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1990]="B"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1991]="B"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1992]="C"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1993]="C"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1994]="C"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1995]="C"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1996]="C"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1997]="D"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1998]="D"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==1999]="D"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2000]="D"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2001]="D"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2002]="E"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2003]="E"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2004]="E"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2005]="E"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2006]="E"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2007]="F"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2008]="F"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2009]="F"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2010]="F"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2011]="F"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2012]="G"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2013]="G"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2014]="G"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2015]="G"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2016]="G"
eiders.ddl$r$fiveyear[eiders.ddl$r$time==2017]="H"

eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1982]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1983]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1984]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1985]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1986]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1987]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1988]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1989]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1990]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1991]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1992]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1993]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1994]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1995]="A"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1996]="B"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1997]="B"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1998]="B"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==1999]="C"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2000]="C"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2001]="C"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2002]="D"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2003]="D"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2004]="D"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2005]="E"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2006]="E"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2007]="E"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2008]="F"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2009]="F"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2010]="F"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2011]="G"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2012]="G"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2013]="G"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2014]="H"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2015]="H"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2016]="H"
eiders.ddl$S$threeyearpostninetyfive[eiders.ddl$S$time==2017]="I"

eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1982]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1983]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1984]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1985]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1986]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1987]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1988]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1989]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1990]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1991]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1992]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1993]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1994]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1995]="A"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1996]="B"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1997]="B"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1998]="B"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==1999]="C"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2000]="C"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2001]="C"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2002]="D"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2003]="D"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2004]="D"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2005]="E"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2006]="E"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2007]="E"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2008]="F"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2009]="F"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2010]="F"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2011]="G"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2012]="G"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2013]="G"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2014]="H"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2015]="H"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2016]="H"
eiders.ddl$r$threeyearpostninetyfive[eiders.ddl$r$time==2017]="I"

eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1982]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1983]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1984]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1985]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1986]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1987]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1988]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1989]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1990]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1991]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1992]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1993]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1994]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1995]="A"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1996]="B"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1997]="B"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1998]="B"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==1999]="B"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2000]="B"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2001]="C"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2002]="C"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2003]="C"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2004]="C"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2005]="C"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2006]="D"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2007]="D"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2008]="D"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2009]="D"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2010]="D"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2011]="E"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2012]="E"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2013]="E"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2014]="E"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2015]="E"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2016]="F"
eiders.ddl$S$fiveyearpostninetyfive[eiders.ddl$S$time==2017]="F"

eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1982]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1983]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1984]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1985]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1986]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1987]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1988]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1989]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1990]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1991]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1992]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1993]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1994]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1995]="A"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1996]="B"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1997]="B"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1998]="B"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==1999]="B"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2000]="B"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2001]="C"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2002]="C"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2003]="C"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2004]="C"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2005]="C"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2006]="D"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2007]="D"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2008]="D"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2009]="D"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2010]="D"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2011]="E"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2012]="E"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2013]="E"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2014]="E"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2015]="E"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2016]="F"
eiders.ddl$r$fiveyearpostninetyfive[eiders.ddl$r$time==2017]="F"


## Next, specify parameters to be used in the models
Sdot=list(formula=~1)
Stime=list(formula=~time)
Ssite=list(formula=~site)
Stimesite=list(formula=~time+site)
Stime.site=list(formula=~time*site)
Sthreeyear=list(formula=~threeyear)
Sthreeyearsite=list(formula=~threeyear+site)
Sthreeyear.site=list(formula=~threeyear*site)
Sfiveyear=list(formula=~fiveyear)
Sfiveyearsite=list(formula=~fiveyear+site)
Sfiveyear.site=list(formula=~fiveyear*site)
Sthreeyearpostninetyfive=list(formula=~threeyearpostninetyfive)
Sthreeyearpostninetyfivesite=list(formula=~threeyearpostninetyfive+site)
Sthreeyearpostninetyfive.site=list(formula=~threeyearpostninetyfive*site)
Sfiveyearpostninetyfive=list(formula=~fiveyearpostninetyfive)
Sfiveyearpostninetyfivesite=list(formula=~fiveyearpostninetyfive+site)
Sfiveyearpostninetyfive.site=list(formula=~fiveyearpostninetyfive*site)


rdot=list(formula=~1)
rtime=list(formula=~time)
rsite=list(formula=~site)
rtimesite=list(formula=~time+site)
rtime.site=list(formula=~time*site)
rthreeyear=list(formula=~threeyear)
rthreeyearsite=list(formula=~threeyear+site)
rthreeyear.site=list(formula=~threeyear*site)
rfiveyear=list(formula=~fiveyear)
rfiveyearsite=list(formula=~fiveyear+site)
rfiveyear.site=list(formula=~fiveyear*site)
rthreeyearpostninetyfive=list(formula=~threeyearpostninetyfive)
rthreeyearpostninetyfivesite=list(formula=~threeyearpostninetyfive+site)
rthreeyearpostninetyfive.site=list(formula=~threeyearpostninetyfive*site)
rfiveyearpostninetyfive=list(formula=~fiveyearpostninetyfive)
rfiveyearpostninetyfivesite=list(formula=~fiveyearpostninetyfive+site)
rfiveyearpostninetyfive.site=list(formula=~fiveyearpostninetyfive*site)


## Run the spatial and temporal models
eiders.Sdot.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rdot))
eiders.Stime.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rdot))
eiders.Ssite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rdot))
eiders.Stimesite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rdot))
eiders.Stime.site.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rdot))
eiders.Sdot.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rtime))
eiders.Stime.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rtime))
eiders.Ssite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rtime))
eiders.Stimesite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rtime))
eiders.Stime.site.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rtime))
eiders.Sdot.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rsite))
eiders.Stime.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rsite))
eiders.Ssite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rsite))
eiders.Stimesite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rsite))
eiders.Stime.site.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rsite))
eiders.Sdot.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rtimesite))
eiders.Stime.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rtimesite))
eiders.Ssite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rtimesite))
eiders.Stimesite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rtimesite))
eiders.Stime.site.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rtimesite))
eiders.Sdot.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rtime.site))
eiders.Stime.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rtime.site))
eiders.Ssite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rtime.site))
eiders.Stimesite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rtime.site))
eiders.Stime.site.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rtime.site))

eiders.Sthreeyear.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rdot))
eiders.Sthreeyearsite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rdot))
eiders.Sthreeyear.site.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rdot))
eiders.Sdot.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rthreeyear))
eiders.Sthreeyear.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rthreeyear))
eiders.Ssite.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rthreeyear))
eiders.Sthreeyearsite.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rthreeyear))
eiders.Sthreeyear.site.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rthreeyear))
eiders.Sthreeyear.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rsite))
eiders.Sthreeyearsite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rsite))
eiders.Sthreeyear.site.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rsite))
eiders.Sdot.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rthreeyearsite))
eiders.Sthreeyear.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rthreeyearsite))
eiders.Ssite.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rthreeyearsite))
eiders.Sthreeyearsite.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rthreeyearsite))
eiders.Sthreeyear.site.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rthreeyearsite))
eiders.Sdot.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rthreeyear.site))
eiders.Sthreeyear.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rthreeyear.site))
eiders.Ssite.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rthreeyear.site))
eiders.Sthreeyearsite.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rthreeyear.site))
eiders.Sthreeyear.site.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rthreeyear.site))

eiders.Sfiveyear.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rdot))
eiders.Sfiveyearsite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rdot))
eiders.Sfiveyear.site.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rdot))
eiders.Sfiveyear.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rfiveyear))
eiders.Sfiveyearsite.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rfiveyear))
eiders.Sfiveyear.site.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rfiveyear))
eiders.Sfiveyear.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rsite))
eiders.Sfiveyearsite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rsite))
eiders.Sfiveyear.site.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rsite))
eiders.Sfiveyear.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rfiveyearsite))
eiders.Sfiveyearsite.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rfiveyearsite))
eiders.Sfiveyear.site.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rfiveyearsite))
eiders.Sfiveyear.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rfiveyear.site))
eiders.Sfiveyearsite.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rfiveyear.site))
eiders.Sfiveyear.site.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rfiveyear.site))
eiders.Sdot.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rfiveyear))
eiders.Sdot.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rfiveyear.site))
eiders.Sdot.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rfiveyearsite))
eiders.Ssite.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rfiveyear))
eiders.Ssite.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rfiveyearsite))
eiders.Ssite.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rfiveyear.site))

eiders.Sthreeyearpostninetyfive.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rdot))
eiders.Sthreeyearpostninetyfivesite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rdot))
eiders.Sthreeyearpostninetyfive.site.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rdot))
eiders.Sthreeyearpostninetyfive.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rthreeyearpostninetyfive))
eiders.Sthreeyearpostninetyfivesite.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rthreeyearpostninetyfive))
eiders.Sthreeyearpostninetyfive.site.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rthreeyearpostninetyfive))
eiders.Sthreeyearpostninetyfive.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rsite))
eiders.Sthreeyearpostninetyfivesite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rsite))
eiders.Sthreeyearpostninetyfive.site.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rsite))
eiders.Sthreeyearpostninetyfive.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rthreeyearpostninetyfivesite))
eiders.Sthreeyearpostninetyfivesite.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rthreeyearpostninetyfivesite))
eiders.Sthreeyearpostninetyfive.site.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rthreeyearpostninetyfivesite))
eiders.Sthreeyearpostninetyfive.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rthreeyearpostninetyfive.site))
eiders.Sthreeyearpostninetyfivesite.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rthreeyearpostninetyfive.site))
eiders.Sthreeyearpostninetyfive.site.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rthreeyearpostninetyfive.site))
eiders.Sdot.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rthreeyearpostninetyfive))
eiders.Sdot.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rthreeyearpostninetyfive.site))
eiders.Sdot.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rthreeyearpostninetyfivesite))
eiders.Ssite.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rthreeyearpostninetyfive))
eiders.Ssite.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rthreeyearpostninetyfivesite))
eiders.Ssite.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rthreeyearpostninetyfive.site))

eiders.Sfiveyearpostninetyfive.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rdot))
eiders.Sfiveyearpostninetyfivesite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rdot))
eiders.Sfiveyearpostninetyfive.site.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rdot))
eiders.Sfiveyearpostninetyfive.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rfiveyearpostninetyfive))
eiders.Sfiveyearpostninetyfivesite.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rfiveyearpostninetyfive))
eiders.Sfiveyearpostninetyfive.site.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rfiveyearpostninetyfive))
eiders.Sfiveyearpostninetyfive.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rsite))
eiders.Sfiveyearpostninetyfivesite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rsite))
eiders.Sfiveyearpostninetyfive.site.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rsite))
eiders.Sfiveyearpostninetyfive.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rfiveyearpostninetyfivesite))
eiders.Sfiveyearpostninetyfivesite.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rfiveyearpostninetyfivesite))
eiders.Sfiveyearpostninetyfive.site.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rfiveyearpostninetyfivesite))
eiders.Sfiveyearpostninetyfive.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rfiveyearpostninetyfive.site))
eiders.Sfiveyearpostninetyfivesite.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rfiveyearpostninetyfive.site))
eiders.Sfiveyearpostninetyfive.site.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rfiveyearpostninetyfive.site))
eiders.Sdot.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rfiveyearpostninetyfive))
eiders.Sdot.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rfiveyearpostninetyfive.site))
eiders.Sdot.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rfiveyearpostninetyfivesite))
eiders.Ssite.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rfiveyearpostninetyfive))
eiders.Ssite.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rfiveyearpostninetyfivesite))
eiders.Ssite.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rfiveyearpostninetyfive.site))

eiders.Stime.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rthreeyear))
eiders.Stimesite.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rthreeyear))
eiders.Stime.site.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rthreeyear))
eiders.Stime.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rthreeyearsite))
eiders.Stime.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rthreeyear.site))
eiders.Stimesite.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rthreeyearsite))
eiders.Stimesite.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rthreeyear.site))
eiders.Stime.site.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rthreeyearsite))
eiders.Stime.site.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rthreeyear.site))

eiders.Stime.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rfiveyear))
eiders.Stimesite.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rfiveyear))
eiders.Stime.site.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rfiveyear))
eiders.Stime.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rfiveyearsite))
eiders.Stime.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rfiveyear.site))
eiders.Stimesite.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rfiveyearsite))
eiders.Stimesite.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rfiveyear.site))
eiders.Stime.site.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rfiveyearsite))
eiders.Stime.site.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rfiveyear.site))

eiders.Stime.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rthreeyearpostninetyfive))
eiders.Stimesite.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rthreeyearpostninetyfive))
eiders.Stime.site.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rthreeyearpostninetyfive))
eiders.Stime.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rthreeyearpostninetyfivesite))
eiders.Stime.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rthreeyearpostninetyfive.site))
eiders.Stimesite.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rthreeyearpostninetyfivesite))
eiders.Stimesite.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rthreeyearpostninetyfive.site))
eiders.Stime.site.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rthreeyearpostninetyfivesite))
eiders.Stime.site.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rthreeyearpostninetyfive.site))

eiders.Stime.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rfiveyearpostninetyfive))
eiders.Stimesite.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rfiveyearpostninetyfive))
eiders.Stime.site.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rfiveyearpostninetyfive))
eiders.Stime.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rfiveyearpostninetyfivesite))
eiders.Stime.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rfiveyearpostninetyfive.site))
eiders.Stimesite.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rfiveyearpostninetyfivesite))
eiders.Stimesite.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rfiveyearpostninetyfive.site))
eiders.Stime.site.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rfiveyearpostninetyfivesite))
eiders.Stime.site.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rfiveyearpostninetyfive.site))

eiders.Sthreeyear.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rfiveyearpostninetyfive))
eiders.Sthreeyearsite.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rfiveyearpostninetyfive))
eiders.Sthreeyear.site.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rfiveyearpostninetyfive))
eiders.Sthreeyear.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rfiveyearpostninetyfivesite))
eiders.Sthreeyear.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rfiveyearpostninetyfive.site))
eiders.Sthreeyearsite.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rfiveyearpostninetyfivesite))
eiders.Sthreeyearsite.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rfiveyearpostninetyfive.site))
eiders.Sthreeyear.site.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rfiveyearpostninetyfivesite))
eiders.Sthreeyear.site.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rfiveyearpostninetyfive.site))

eiders.Sthreeyear.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rthreeyearpostninetyfive))
eiders.Sthreeyearsite.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rthreeyearpostninetyfive))
eiders.Sthreeyear.site.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rthreeyearpostninetyfive))
eiders.Sthreeyear.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rthreeyearpostninetyfivesite))
eiders.Sthreeyear.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rthreeyearpostninetyfive.site))
eiders.Sthreeyearsite.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rthreeyearpostninetyfivesite))
eiders.Sthreeyearsite.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rthreeyearpostninetyfive.site))
eiders.Sthreeyear.site.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rthreeyearpostninetyfivesite))
eiders.Sthreeyear.site.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rthreeyearpostninetyfive.site))

eiders.Sthreeyear.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rfiveyear))
eiders.Sthreeyearsite.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rfiveyear))
eiders.Sthreeyear.site.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rfiveyear))
eiders.Sthreeyear.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rfiveyearsite))
eiders.Sthreeyear.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rfiveyear.site))
eiders.Sthreeyearsite.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rfiveyearsite))
eiders.Sthreeyearsite.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rfiveyear.site))
eiders.Sthreeyear.site.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rfiveyearsite))
eiders.Sthreeyear.site.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rfiveyear.site))

eiders.Sthreeyear.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rtime))
eiders.Sthreeyearsite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rtime))
eiders.Sthreeyear.site.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rtime))
eiders.Sthreeyear.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rtimesite))
eiders.Sthreeyear.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear,r=rtime.site))
eiders.Sthreeyearsite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rtimesite))
eiders.Sthreeyearsite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearsite,r=rtime.site))
eiders.Sthreeyear.site.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rtimesite))
eiders.Sthreeyear.site.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyear.site,r=rtime.site))

eiders.Sfiveyear.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rtime))
eiders.Sfiveyearsite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rtime))
eiders.Sfiveyear.site.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rtime))
eiders.Sfiveyear.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rtimesite))
eiders.Sfiveyear.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rtime.site))
eiders.Sfiveyearsite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rtimesite))
eiders.Sfiveyearsite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rtime.site))
eiders.Sfiveyear.site.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rtimesite))
eiders.Sfiveyear.site.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rtime.site))

eiders.Sthreeyearpostninetyfive.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rtime))
eiders.Sthreeyearpostninetyfivesite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rtime))
eiders.Sthreeyearpostninetyfive.site.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rtime))
eiders.Sthreeyearpostninetyfive.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rtimesite))
eiders.Sthreeyearpostninetyfive.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rtime.site))
eiders.Sthreeyearpostninetyfivesite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rtimesite))
eiders.Sthreeyearpostninetyfivesite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rtime.site))
eiders.Sthreeyearpostninetyfive.site.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rtimesite))
eiders.Sthreeyearpostninetyfive.site.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rtime.site))

eiders.Sfiveyearpostninetyfive.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rtime))
eiders.Sfiveyearpostninetyfivesite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rtime))
eiders.Sfiveyearpostninetyfive.site.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rtime))
eiders.Sfiveyearpostninetyfive.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rtimesite))
eiders.Sfiveyearpostninetyfive.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rtime.site))
eiders.Sfiveyearpostninetyfivesite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rtimesite))
eiders.Sfiveyearpostninetyfivesite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rtime.site))
eiders.Sfiveyearpostninetyfive.site.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rtimesite))
eiders.Sfiveyearpostninetyfive.site.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rtime.site))

eiders.Sfiveyearpostninetyfive.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rthreeyear))
eiders.Sfiveyearpostninetyfivesite.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rthreeyear))
eiders.Sfiveyearpostninetyfive.site.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rthreeyear))
eiders.Sfiveyearpostninetyfive.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rthreeyearsite))
eiders.Sfiveyearpostninetyfive.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rthreeyear.site))
eiders.Sfiveyearpostninetyfivesite.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rthreeyearsite))
eiders.Sfiveyearpostninetyfivesite.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rthreeyear.site))
eiders.Sfiveyearpostninetyfive.site.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rthreeyearsite))
eiders.Sfiveyearpostninetyfive.site.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rthreeyear.site))

eiders.Sfiveyearpostninetyfive.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rthreeyearpostninetyfive))
eiders.Sfiveyearpostninetyfivesite.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rthreeyearpostninetyfive))
eiders.Sfiveyearpostninetyfive.site.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rthreeyearpostninetyfive))
eiders.Sfiveyearpostninetyfive.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rthreeyearpostninetyfivesite))
eiders.Sfiveyearpostninetyfive.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rthreeyearpostninetyfive.site))
eiders.Sfiveyearpostninetyfivesite.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rthreeyearpostninetyfivesite))
eiders.Sfiveyearpostninetyfivesite.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rthreeyearpostninetyfive.site))
eiders.Sfiveyearpostninetyfive.site.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rthreeyearpostninetyfivesite))
eiders.Sfiveyearpostninetyfive.site.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rthreeyearpostninetyfive.site))

eiders.Sfiveyearpostninetyfive.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rfiveyear))
eiders.Sfiveyearpostninetyfivesite.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rfiveyear))
eiders.Sfiveyearpostninetyfive.site.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rfiveyear))
eiders.Sfiveyearpostninetyfive.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rfiveyearsite))
eiders.Sfiveyearpostninetyfive.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive,r=rfiveyear.site))
eiders.Sfiveyearpostninetyfivesite.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rfiveyearsite))
eiders.Sfiveyearpostninetyfivesite.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfivesite,r=rfiveyear.site))
eiders.Sfiveyearpostninetyfive.site.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rfiveyearsite))
eiders.Sfiveyearpostninetyfive.site.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearpostninetyfive.site,r=rfiveyear.site))

eiders.Sthreeyearpostninetyfive.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rfiveyear))
eiders.Sthreeyearpostninetyfivesite.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rfiveyear))
eiders.Sthreeyearpostninetyfive.site.rfiveyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rfiveyear))
eiders.Sthreeyearpostninetyfive.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rfiveyearsite))
eiders.Sthreeyearpostninetyfive.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rfiveyear.site))
eiders.Sthreeyearpostninetyfivesite.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rfiveyearsite))
eiders.Sthreeyearpostninetyfivesite.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rfiveyear.site))
eiders.Sthreeyearpostninetyfive.site.rfiveyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rfiveyearsite))
eiders.Sthreeyearpostninetyfive.site.rfiveyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rfiveyear.site))

eiders.Sthreeyearpostninetyfive.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rthreeyear))
eiders.Sthreeyearpostninetyfivesite.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rthreeyear))
eiders.Sthreeyearpostninetyfive.site.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rthreeyear))
eiders.Sthreeyearpostninetyfive.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rthreeyearsite))
eiders.Sthreeyearpostninetyfive.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rthreeyear.site))
eiders.Sthreeyearpostninetyfivesite.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rthreeyearsite))
eiders.Sthreeyearpostninetyfivesite.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rthreeyear.site))
eiders.Sthreeyearpostninetyfive.site.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rthreeyearsite))
eiders.Sthreeyearpostninetyfive.site.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rthreeyear.site))

eiders.Sthreeyearpostninetyfive.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rfiveyearpostninetyfive))
eiders.Sthreeyearpostninetyfivesite.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rfiveyearpostninetyfive))
eiders.Sthreeyearpostninetyfive.site.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rfiveyearpostninetyfive))
eiders.Sthreeyearpostninetyfive.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rfiveyearpostninetyfivesite))
eiders.Sthreeyearpostninetyfive.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive,r=rfiveyearpostninetyfive.site))
eiders.Sthreeyearpostninetyfivesite.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rfiveyearpostninetyfivesite))
eiders.Sthreeyearpostninetyfivesite.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfivesite,r=rfiveyearpostninetyfive.site))
eiders.Sthreeyearpostninetyfive.site.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rfiveyearpostninetyfivesite))
eiders.Sthreeyearpostninetyfive.site.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sthreeyearpostninetyfive.site,r=rfiveyearpostninetyfive.site))

eiders.Sfiveyear.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rfiveyearpostninetyfive))
eiders.Sfiveyearsite.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rfiveyearpostninetyfive))
eiders.Sfiveyear.site.rfiveyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rfiveyearpostninetyfive))
eiders.Sfiveyear.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rfiveyearpostninetyfivesite))
eiders.Sfiveyear.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rfiveyearpostninetyfive.site))
eiders.Sfiveyearsite.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rfiveyearpostninetyfivesite))
eiders.Sfiveyearsite.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rfiveyearpostninetyfive.site))
eiders.Sfiveyear.site.rfiveyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rfiveyearpostninetyfivesite))
eiders.Sfiveyear.site.rfiveyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rfiveyearpostninetyfive.site))

eiders.Sfiveyear.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rthreeyear))
eiders.Sfiveyearsite.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rthreeyear))
eiders.Sfiveyear.site.rthreeyear=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rthreeyear))
eiders.Sfiveyear.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rthreeyearsite))
eiders.Sfiveyear.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rthreeyear.site))
eiders.Sfiveyearsite.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rthreeyearsite))
eiders.Sfiveyearsite.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rthreeyear.site))
eiders.Sfiveyear.site.rthreeyearsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rthreeyearsite))
eiders.Sfiveyear.site.rthreeyear.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rthreeyear.site))

eiders.Sfiveyear.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rthreeyearpostninetyfive))
eiders.Sfiveyearsite.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rthreeyearpostninetyfive))
eiders.Sfiveyear.site.rthreeyearpostninetyfive=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rthreeyearpostninetyfive))
eiders.Sfiveyear.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rthreeyearpostninetyfivesite))
eiders.Sfiveyear.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear,r=rthreeyearpostninetyfive.site))
eiders.Sfiveyearsite.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rthreeyearpostninetyfivesite))
eiders.Sfiveyearsite.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyearsite,r=rthreeyearpostninetyfive.site))
eiders.Sfiveyear.site.rthreeyearpostninetyfivesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rthreeyearpostninetyfivesite))
eiders.Sfiveyear.site.rthreeyearpostninetyfive.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sfiveyear.site,r=rthreeyearpostninetyfive.site))


## Collate the model results and adjust for c-hat value (determined in a separate analysis in Program MARK), and export results
model.list=collect.models(type="Recovery")
adjusted.models<-adjust.chat(chat = 1.374, model.list)
my.models<-model.table(adjusted.models)
my.models
write.csv(my.models, "Eider_recovery_models.csv")


## Export parameter estimates from best-supported model
survival.estimates<-get.real(eiders.Sthreeyearpostninetyfive.rfiveyear.site, "S", se=TRUE)
write.csv(survival.estimates, "realsurvivalestimates2.csv")
recovery.estimates<-get.real(eiders.Sthreeyearpostninetyfive.rfiveyear.site, "r", se=TRUE)
write.csv(recovery.estimates, "realrecoveryestimates2.csv")

## Remove files before second part of the analysis
cleanup(ask=FALSE)




